@@ -5,9 +5,10 @@ kerake = "bcdfghjklmnpqrstvwxz"
 kerake = list( kerake + kerake.upper() )
 vokaali = "aeiouyäöå"
 vokaali = list( vokaali + vokaali.upper() )
-pitkat = ['yi', 'öi', 'äi', 'ui', 'oi', 'ai', 'äy', 'au', 'yö', 'öy', 'uo', 'ou', 'ie', 'ei', 'eu', 'iu', 'ey', 'iy',
-			'aa', 'ii', 'uu', 'ee', 'oo', 'yy', 'ää', 'öö']			# suomen pitkät vokaalit ja diftongit
-pitkat = pitkat + [a.upper() for a in pitkat] + [a[0].upper()+a[1] for a in pitkat] + [a[0]+a[1].upper() for a in pitkat]
+# suomen pitkät vokaalit ja diftongit
+pitkat = ['yi', 'öi', 'äi', 'ui', 'oi', 'ai', 'äy', 'au', 'yö', 'öy', 'uo', 'ou', 'ie',
+ 'ei', 'eu', 'iu', 'ey', 'iy', 'aa', 'ii', 'uu', 'ee', 'oo', 'yy', 'ää', 'öö']
+pitkat = pitkat + [a.upper() for a in pitkat] + [a[0].upper()+a[1] for a in pitkat] + [a[0]+a[1].upper() for a in pitkat] # O(2^n) mut mitä välii ku maksimitapaus on n=2 :D
 
 def syllables(sana):
 	tavut = []
@@ -87,6 +88,41 @@ def add_hyphens(tavut, sana, hyphen, margin):
 			tavutettava += hyphen
 	return tavutettava
 
+def hyp_html(tavuttamaton_osa, margin=2, hyphen='\u00AD'):
+	tavutettu = ''
+	while len(tavuttamaton_osa) > 0:
+		raja_asti = tavuttamaton_osa.find('<')
+		if raja_asti != -1:
+			tavutettava_osa = tavuttamaton_osa[:raja_asti]
+			tavuttamaton_osa = tavuttamaton_osa[raja_asti:]
+			tavutettu += hyp_text(tavutettava_osa, margin, hyphen)
+		else:
+			tavutettava_osa = tavuttamaton_osa
+			tavuttamaton_osa = ''
+			tavutettu += hyp_text(tavutettava_osa, margin, hyphen)
+		raja_alkaen = tavuttamaton_osa.find('>')
+		if raja_alkaen != -1:
+			tavutettu += tavuttamaton_osa[:raja_alkaen+1]
+			tavuttamaton_osa = tavuttamaton_osa[raja_alkaen+1:]
+	return tavutettu
+
+def hyp_text(text, margin=2, hyphen='\u00AD'):
+	valmis_teksti = []
+	for rivi in text.split('\n'):
+		valmis_rivi = []
+		for sana in rivi.split(' '):
+	
+			tavut = syllables(sana)
+			sana = add_hyphens(tavut, sana, hyphen, margin)
+
+			valmis_rivi.append( sana )
+			
+		valmis_rivi = ' '.join(valmis_rivi)
+		valmis_teksti.append(valmis_rivi)
+	valmis_teksti = '\n'.join(valmis_teksti)
+	return valmis_teksti
+	
+
 def hyphenate(text, margin=2, skip_html=False, hyphen='\u00AD'):
 	"""hyphenate_finnish(text, margin=2, skip_html=False, hyphen='\u00AD')
 
@@ -106,44 +142,13 @@ def hyphenate(text, margin=2, skip_html=False, hyphen='\u00AD'):
 	
 	if margin < 1:
 		margin = 1
-
-	skipataan = False
-	valmis_teksti = []
 	
-	for rivi in text.split('\n'):
-		valmis_rivi = []
-		for sana in rivi.split(' '):
-		
-			if skip_html:
-				if not skipataan and "<" in sana:
-					skipataan = True
-					eka = sana.find('<')
-					tavutettava_osa = sana[:eka]
-					tavut = syllables(tavutettava_osa)
-					tavutettu = add_hyphens(tavut, tavutettava_osa, hyphen, margin)
-					sana = tavutettu + sana[eka:]
-		
-				if skipataan:
-					if ">" in sana and sana.rfind('>') > sana.rfind('<'):
-						skipataan = False
-						vika = sana.rfind('>')+1
-						tavutettava_osa = sana[vika:]
-						tavut = syllables(tavutettava_osa)
-						tavutettu = add_hyphens(tavut, tavutettava_osa, hyphen, margin)
-						sana = sana[:vika] + tavutettu
-					valmis_rivi.append(sana)
-					continue
-			
-			tavut = syllables(sana)
-			sana = add_hyphens(tavut, sana, hyphen, margin)
+	if skip_html:
+		return hyp_html(text, margin, hyphen)
+	else:
+		return hyp_text(text, margin, hyphen)
+
 
-			valmis_rivi.append( sana )
-			
-		valmis_rivi = ' '.join(valmis_rivi)
-		valmis_teksti.append(valmis_rivi)
-	valmis_teksti = '\n'.join(valmis_teksti)
-	return valmis_teksti
-	
 if __name__ == "__main__":
 	import sys
 	try:
