@@ -6,8 +6,9 @@ def testaa(tavutus, oikea_vastaus, testinimi):
 	if tavutus == oikea_vastaus:
 		print (testinimi+" läpi!")
 	else:
-		print (testinimi+" fail!")
-		print (tavutus)
+		print (testinimi+" FAAAAAAIILLLLL!")
+		print ("tässä on pieleen mennyt: "+tavutus)
+		print ("tässä on oikea vastaus: "+oikea_vastaus)
 		for i, c in enumerate(tavutus):
 			try:
 				if c != oikea_vastaus[i]:
@@ -40,7 +41,21 @@ Tarkempaa tietoa kurssista
 ### Japanin tavukirjoitus heti alkuun
 Kana-tavukirjoitusjärjestelmä on lukutaidon perusta, jota ilman japani on räpiköintiä. Japanilaiset oppivat kanat esikoulussa, joten niissä ei ole mitään niin vaikeaa, ettetkö sinäkin oppisi niitä helposti! Opiskelemme kanat pikavauhtia alta pois, jotta pääsemme etenemään itse kieleen vauhdilla.
 '''
-
+teksti10='''
+<html>
+<head>
+	<title>REDbot: &lt;http://uchi.drasa.eu:8081/twitter&gt;</title>
+	<meta http-equiv="content-type" content="text/html; charset=utf-8" />
+	<meta name="ROBOTS" content="INDEX, NOFOLLOW" />
+    <link rel="stylesheet" type="text/css" href="static/style.css">
+	<!--[if IE]> 
+    <style type="text/css">
+        #right_column {
+        	width: 650px;
+            float: left;
+    </style>
+    <![endif]-->
+'''
 teksti_c1 = '''
 Ja-pa-ni-har-ras-ta-ja!!
 ==================
@@ -68,16 +83,44 @@ Ta-va-taan kurs-sil-la!<br/>
 kurs-sin o-pet-ta-ja<br/>
 </p>
 '''
+
+teksti_c10='''
+<html>
+<head>
+	<title>RED-bot: &lt;htt-p://uc-hi.dra-sa.eu:8081/twit-ter&gt;</title>
+	<meta http-equiv="content-type" content="text/html; charset=utf-8" />
+	<meta name="ROBOTS" content="INDEX, NOFOLLOW" />
+    <link rel="stylesheet" type="text/css" href="static/style.css">
+	<!--[if IE]> 
+    <style type="text/css">
+        #right_co-lumn {
+        	width: 650px;
+            flo-at: left;
+    </style>
+    <![endif]-->
+'''
+
 tavutus = hyphenate(teksti1, skip_html=True, margin=1, hyphen='-')
-testaa(tavutus, teksti_c1, "Testi 1")
+testaa(tavutus, teksti_c1, "Testi 1, perustekstii")
 tavutus = hyphenate(teksti2, skip_html=True, margin=1, hyphen='-')
-testaa(tavutus, teksti_c2, "Testi 2")
+testaa(tavutus, teksti_c2, "Testi 2, html:ää!")
 tavutus = hyphenate(teksti3, skip_html=True, margin=1, hyphen='-')
-testaa(tavutus, teksti_c3, "Testi 3")
-testaa(hyphenate('Murr'), "Murr", "Testi 4")
+testaa(tavutus, teksti_c3, "Testi 3, perustekstii")
+testaa(hyphenate('Murr'), "Murr", "Testi 4, yksittäiset tavut ovat erikoisia vrt 'mur-ri'")
 tavutus = hyphenate(teksti2, skip_html=False, margin=1, hyphen='-')
-testaa(tavutus, teksti_c5	, "Testi 5")
+testaa(tavutus, teksti_c5	, "Testi 5, html-tagitkin iloisesti tavuttajaan")
 tavutus = hyphenate("<p>testataanpa</p>", skip_html=True, margin=1, hyphen='-')
-testaa(tavutus, "<p>testataanpa</p>"	, "Testi 6")
+testaa(tavutus, "<p>tes-ta-taan-pa</p>"	, "Testi 6, yksi sana html-tagien ympäröimänä")
 tavutus = hyphenate("<p>testataanpa tätä</p>", skip_html=True, margin=1, hyphen='-')
-testaa(tavutus, "<p>tes-ta-taan-pa tä-tä</p>"	, "Testi 7")
\ No newline at end of file
+testaa(tavutus, "<p>tes-ta-taan-pa tä-tä</p>", "Testi 7, kaksi sanaa html-tagien ympäröimänä")
+### HUOM: nämä failaa koska yhdyssanat. Liian vaikeeta >__<
+tavutus = hyphenate("seitsemäntsiljoonaa", skip_html=False, margin=1, hyphen='-')
+testaa(tavutus, "sei-se-män-tsil-joo-naa"	, "Testi 8, yhdyssanaa ja konsonanttiklusteria")
+### HUOM: nämä failaa koska yhdyssanat. Liian vaikeeta >__<
+tavutus = hyphenate("kannelskruudaaja", skip_html=False, margin=1, hyphen='-')
+testaa(tavutus, "kan-nel-skruu-daa-ja", "Testi 9, yhdyssanaa ja konsonanttiklusteria")
+### HUOM: uchi pitäisi taivuttaa u-chi, mutta en ole jaksanut tehä tarpeeksi hienoa systeemiä. No, se ei oo tän testin pointti.
+tavutus = hyphenate(teksti10, skip_html=True, margin=1, hyphen='-')
+testaa(tavutus, teksti_c10, "Testi 10, html:ää")
+tavutus = hyphenate("mäntsälä", skip_html=False, margin=1, hyphen='-')
+testaa(tavutus, "mänt-sä-lä", "Testi 11, suomenkielinen tavu VOI loppua 'nt'")
\ No newline at end of file
